<?php
if( !defined( 'ABSPATH')){ exit(); }

/*
Общие функции, которые необходимо
вызывать первыми
*/

/*
Подключаем фильтр к письмам, что бы все письма отображались как HTML
*/
add_filter('wp_mail_content_type', create_function('', 'return "text/html";'));

/*
Данные, которые независимо от настроек мультиязычности, всегда будут указывать на оригинал
*/
global $or_template_directory;
$or_template_directory = get_template_directory_uri();

global $or_site_url;
$or_site_url = rtrim(get_option('siteurl'), '/');

/*
Отключаем пингбеки из-за возможной атаки.
*/
add_filter( 'xmlrpc_enabled', '__return_false' );
add_filter( 'wp_xmlrpc_server_class', 'disable_wp_xmlrpc_server_class' );
function disable_wp_xmlrpc_server_class() {
	return 'disable_wp_xmlrpc_server_class';
}
class disable_wp_xmlrpc_server_class {
	function serve_request() {
		echo 'XMLRPC disabled';
	}
}
add_filter( 'xmlrpc_methods', 'pn_remove_pingback_method' );
function pn_remove_pingback_method( $methods ) {
	unset( $methods['pingback.ping'] );
	unset( $methods['pingback.extensions.getPingbacks'] );
	return $methods;
}

add_filter( 'wp_headers', 'pn_remove_x_pingback_header' );
function pn_remove_x_pingback_header( $headers ) {
	unset( $headers['X-Pingback'] );
	return $headers;
}

/* увеличиваем время жизни сессии */
function pn_auth_cookie_expiration( $expiration, $user_id, $remember ){
    
    $expiration = 3 * DAY_IN_SECONDS;

    return $expiration;
} 
add_filter( 'auth_cookie_expiration','pn_auth_cookie_expiration', 10, 3 );

/* 
Новым файлам, которые будут работать в админке,
задаём свойство админ-панели
*/
$admin_files = array('tosaved','toajax','adminjs','quicktags','style');
if(in_array(basename($_SERVER['SCRIPT_FILENAME'],'.php'),$admin_files)){
	if(!defined('WP_ADMIN')){
		define('WP_ADMIN', true);
	} 
}

/*
Приводим названия всех файлов, к латинице
*/
add_filter('sanitize_title', 'pn_sanitize_title', 9);
add_filter('sanitize_file_name', 'pn_sanitize_title');
function pn_sanitize_title($title) {
	global $wpdb;

	$iso9_table = array(
		'А' => 'A', 'Б' => 'B', 'В' => 'V', 'Г' => 'G', 'Ѓ' => 'G`',
		'Ґ' => 'G`', 'Д' => 'D', 'Е' => 'E', 'Ё' => 'YO', 'Є' => 'YE',
		'Ж' => 'ZH', 'З' => 'Z', 'Ѕ' => 'Z', 'И' => 'I', 'Й' => 'Y',
		'Ј' => 'J', 'І' => 'I', 'Ї' => 'YI', 'К' => 'K', 'Ќ' => 'K',
		'Л' => 'L', 'Љ' => 'L', 'М' => 'M', 'Н' => 'N', 'Њ' => 'N',
		'О' => 'O', 'П' => 'P', 'Р' => 'R', 'С' => 'S', 'Т' => 'T',
		'У' => 'U', 'Ў' => 'U', 'Ф' => 'F', 'Х' => 'H', 'Ц' => 'TS',
		'Ч' => 'CH', 'Џ' => 'DH', 'Ш' => 'SH', 'Щ' => 'SHH', 'Ъ' => '``',
		'Ы' => 'YI', 'Ь' => '`', 'Э' => 'E`', 'Ю' => 'YU', 'Я' => 'YA',
		'а' => 'a', 'б' => 'b', 'в' => 'v', 'г' => 'g', 'ѓ' => 'g',
		'ґ' => 'g', 'д' => 'd', 'е' => 'e', 'ё' => 'yo', 'є' => 'ye',
		'ж' => 'zh', 'з' => 'z', 'ѕ' => 'z', 'и' => 'i', 'й' => 'y',
		'ј' => 'j', 'і' => 'i', 'ї' => 'yi', 'к' => 'k', 'ќ' => 'k',
		'л' => 'l', 'љ' => 'l', 'м' => 'm', 'н' => 'n', 'њ' => 'n',
		'о' => 'o', 'п' => 'p', 'р' => 'r', 'с' => 's', 'т' => 't',
		'у' => 'u', 'ў' => 'u', 'ф' => 'f', 'х' => 'h', 'ц' => 'ts',
		'ч' => 'ch', 'џ' => 'dh', 'ш' => 'sh', 'щ' => 'shh', 'ь' => '',
		'ы' => 'yi', 'ъ' => "'", 'э' => 'e`', 'ю' => 'yu', 'я' => 'ya'
	);	


	$title = strtr($title, $iso9_table);
	$title = preg_replace("/[^A-Za-z0-9\-\.]/", '-', $title);

	return $title;
}

/* выход */
add_action('myaction_site_logout', 'def_myaction_ajax_logout');
function def_myaction_ajax_logout(){
	
	wp_logout();
	wp_redirect(get_option('siteurl'));
	exit();	
}
/* end выход */

/*
Добавляем новые переменные, с которыми будем работать
*/
add_filter('query_vars', 'pn_add_queryvars');
function pn_add_queryvars( $query_vars ){
		$query_vars[] = 'valut1';
		$query_vars[] = 'valut2';
		$query_vars[] = 'hashed';

		return $query_vars;
}

add_action('generate_rewrite_rules', 'pn_rewriteRules');
function pn_rewriteRules($wp_rewrite) {		
	$rewrite_rules = array (
			'([\-_A-Za-z0-9]+)_([A-Za-z0-9]+)_to_([A-Za-z0-9]+)$' => 'index.php?pagename=$matches[1]&valut1=$matches[2]&valut2=$matches[3]',
			'([\-_A-Za-z0-9]+)/hst_([A-Za-z0-9]{35})$' => 'index.php?pagename=$matches[1]&hashed=$matches[2]',
	);
	$wp_rewrite->rules = array_merge($rewrite_rules, $wp_rewrite->rules);		
}

/* 
дополнительные страницы
*/  
add_action('init', 'pn_rewrite_htaccess');
function pn_rewrite_htaccess(){

	$plugin = basename(PN_PLUGIN_NAME,'.php');
	
	add_rewrite_rule('rtest.html$', 'wp-content/plugins/'. $plugin .'/sitepage/test.php', 'top');
	add_rewrite_rule('ajax-([a-zA-Z0-9\_]+).html?$', 'wp-content/plugins/'. $plugin .'/sitepage/ajax.php?myaction=$1', 'top');
	add_rewrite_rule('cron.html$', 'wp-content/plugins/'. $plugin .'/sitepage/crontab.php', 'top');
	add_rewrite_rule('curscron.html$', 'wp-content/plugins/'. $plugin .'/sitepage/curscron.php', 'top');
	add_rewrite_rule('exportxml.xml$', 'wp-content/plugins/'.$plugin.'/sitepage/exportxml.php', 'top');
	add_rewrite_rule('exporttxt.txt$', 'wp-content/plugins/'.$plugin.'/sitepage/exporttxt.php', 'top');	
	add_rewrite_rule('blackping.html$', 'wp-content/plugins/'.$plugin.'/sitepage/blackping.php', 'top');
	add_rewrite_rule('sitemap.xml$', 'wp-content/plugins/'.$plugin.'/sitepage/sitemap.php', 'top');
	
	/* deprecated */
	add_rewrite_rule('logout.html$', 'wp-content/plugins/'.$plugin.'/sitepage/logout.php', 'top');
	add_rewrite_rule('cronparser.html$', 'wp-content/plugins/'. $plugin .'/sitepage/crontab.php', 'top');
	
}
